==> keycloak-model-map-18.0.2-sources.jar: org/keycloak/models/map/realm/entity/MapIdentityProviderMapperEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapIdentityProviderMapperEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> entityFieldDelegate;
    public MapIdentityProviderMapperEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getIdentityProviderAlias() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_ALIAS);
    }
    @SuppressWarnings("unchecked") @Override public void setIdentityProviderAlias(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_ALIAS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getIdentityProviderMapper() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_MAPPER);
    }
    @SuppressWarnings("unchecked") @Override public void setIdentityProviderMapper(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_MAPPER, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getConfig() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.CONFIG);
    }
    @SuppressWarnings("unchecked") @Override public void setConfig(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.CONFIG, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapIdentityProviderMapperEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapIdentityProviderMapperEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> entityFieldDelegate;
    public MapIdentityProviderMapperEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getIdentityProviderAlias() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_ALIAS);
    }
    @SuppressWarnings("unchecked") @Override public void setIdentityProviderAlias(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_ALIAS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getIdentityProviderMapper() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_MAPPER);
    }
    @SuppressWarnings("unchecked") @Override public void setIdentityProviderMapper(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_MAPPER, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getConfig() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.CONFIG);
    }
    @SuppressWarnings("unchecked") @Override public void setConfig(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.CONFIG, p0);
    }
}
